﻿using System;
using System.Configuration;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace CSSamples.Samples.Overlays
{
    public partial class ShapeFilesOverGoogleMap : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
                Map1.MapUnit = GeographyUnit.Meter;

                Map1.MapTools.OverlaySwitcher.Enabled = true;
                Map1.MapTools.OverlaySwitcher.BackgroundColor = GeoColor.FromHtml("#0065ce");
                Map1.MapTools.MouseCoordinate.Enabled = true;

                GoogleOverlay google = new GoogleOverlay("Google Map");
                google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
                google.GoogleMapType = GoogleMapType.Normal;

                YahooOverlay yahoo = new YahooOverlay("Yahoo Map");
                yahoo.YahooMapType = YahooMapType.Regular;
                yahoo.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["YahooUri"]);

                ShapeFileFeatureLayer shapeFileFeatureLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/USA/STATES.shp"));
                shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(100,212,220,184), GeoColor.FromArgb(255,132,132,154), 1);
                shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                Proj4Projection proj41 = new Proj4Projection();
                proj41.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj41.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                shapeFileFeatureLayer.FeatureSource.Projection = proj41;

                LayerOverlay shapeOverlay = new LayerOverlay("States Overlay", false, TileType.SingleTile);
                shapeOverlay.Layers.Add(shapeFileFeatureLayer);
                shapeOverlay.TransitionEffect = TransitionEffect.None;

                ShapeFileFeatureLayer citiesLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/USA/cities_a.shp"));
                citiesLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City3;
                citiesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                citiesLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = new TextStyle("AREANAME", new GeoFont("Verdana", 9), new GeoSolidBrush(GeoColor.StandardColors.Red));
                citiesLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.HaloPen = new GeoPen(GeoColor.StandardColors.White, 2);

                Proj4Projection proj42 = new Proj4Projection();
                proj42.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj42.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                citiesLayer.FeatureSource.Projection = proj42;

                LayerOverlay cityOverlay = new LayerOverlay("Cities Overlay", false, TileType.SingleTile);
                cityOverlay.Layers.Add(citiesLayer);
                cityOverlay.TransitionEffect = TransitionEffect.None;

                Map1.CustomOverlays.Add(google);
                Map1.CustomOverlays.Add(yahoo);
                Map1.CustomOverlays.Add(shapeOverlay);
                Map1.CustomOverlays.Add(cityOverlay);
            }
        }
    }
}
